# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/staking/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x63osmos/staking/v1beta1/tx.proto\x12\x16\x63osmos.staking.v1beta1\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a$cosmos/staking/v1beta1/staking.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xfb\x04\n\x12MsgCreateValidator\x12P\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32#.cosmos.staking.v1beta1.DescriptionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0b\x64\x65scription\x12R\n\ncommission\x18\x02 \x01(\x0b\x32\'.cosmos.staking.v1beta1.CommissionRatesB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\ncommission\x12`\n\x13min_self_delegation\x18\x03 \x01(\tB0\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\xa8\xe7\xb0*\x01R\x11minSelfDelegation\x12G\n\x11\x64\x65legator_address\x18\x04 \x01(\tB\x1a\x18\x01\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x05 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12\x46\n\x06pubkey\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyB\x18\xca\xb4-\x14\x63osmos.crypto.PubKeyR\x06pubkey\x12:\n\x05value\x18\x07 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x05value:@\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11validator_address\x8a\xe7\xb0*\x1d\x63osmos-sdk/MsgCreateValidator\"\x1c\n\x1aMsgCreateValidatorResponse\"\xa5\x03\n\x10MsgEditValidator\x12P\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32#.cosmos.staking.v1beta1.DescriptionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x0b\x64\x65scription\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12V\n\x0f\x63ommission_rate\x18\x03 \x01(\tB-\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.DecR\x0e\x63ommissionRate\x12W\n\x13min_self_delegation\x18\x04 \x01(\tB\'\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.IntR\x11minSelfDelegation:>\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11validator_address\x8a\xe7\xb0*\x1b\x63osmos-sdk/MsgEditValidator\"\x1a\n\x18MsgEditValidatorResponse\"\x9d\x02\n\x0bMsgDelegate\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12<\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount:9\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0*\x16\x63osmos-sdk/MsgDelegate\"\x15\n\x13MsgDelegateResponse\"\xf6\x02\n\x15MsgTransferDelegation\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12\x43\n\x10receiver_address\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x0freceiverAddress\x12<\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount:C\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0* cosmos-sdk/MsgTransferDelegation\"\x1f\n\x1dMsgTransferDelegationResponse\"\x89\x03\n\x12MsgBeginRedelegate\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12U\n\x15validator_src_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x13validatorSrcAddress\x12U\n\x15validator_dst_address\x18\x03 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x13validatorDstAddress\x12<\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount:@\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0*\x1d\x63osmos-sdk/MsgBeginRedelegate\"p\n\x1aMsgBeginRedelegateResponse\x12R\n\x0f\x63ompletion_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x0e\x63ompletionTime\"\xa1\x02\n\rMsgUndelegate\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12<\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount:;\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0*\x18\x63osmos-sdk/MsgUndelegate\"\xa9\x01\n\x15MsgUndelegateResponse\x12R\n\x0f\x63ompletion_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01R\x0e\x63ompletionTime\x12<\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount\"\xe8\x02\n\x1cMsgCancelUnbondingDelegation\x12\x45\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x10\x64\x65legatorAddress\x12N\n\x11validator_address\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressStringR\x10validatorAddress\x12<\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06\x61mount\x12\'\n\x0f\x63reation_height\x18\x04 \x01(\x03R\x0e\x63reationHeight:J\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\x82\xe7\xb0*\x11\x64\x65legator_address\x8a\xe7\xb0*\'cosmos-sdk/MsgCancelUnbondingDelegation\"&\n$MsgCancelUnbondingDelegationResponse\"\xc5\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x41\n\x06params\x18\x02 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x06params:7\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*$cosmos-sdk/x/staking/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2\x99\x07\n\x03Msg\x12q\n\x0f\x43reateValidator\x12*.cosmos.staking.v1beta1.MsgCreateValidator\x1a\x32.cosmos.staking.v1beta1.MsgCreateValidatorResponse\x12k\n\rEditValidator\x12(.cosmos.staking.v1beta1.MsgEditValidator\x1a\x30.cosmos.staking.v1beta1.MsgEditValidatorResponse\x12\\\n\x08\x44\x65legate\x12#.cosmos.staking.v1beta1.MsgDelegate\x1a+.cosmos.staking.v1beta1.MsgDelegateResponse\x12z\n\x12TransferDelegation\x12-.cosmos.staking.v1beta1.MsgTransferDelegation\x1a\x35.cosmos.staking.v1beta1.MsgTransferDelegationResponse\x12q\n\x0f\x42\x65ginRedelegate\x12*.cosmos.staking.v1beta1.MsgBeginRedelegate\x1a\x32.cosmos.staking.v1beta1.MsgBeginRedelegateResponse\x12\x62\n\nUndelegate\x12%.cosmos.staking.v1beta1.MsgUndelegate\x1a-.cosmos.staking.v1beta1.MsgUndelegateResponse\x12\x8f\x01\n\x19\x43\x61ncelUnbondingDelegation\x12\x34.cosmos.staking.v1beta1.MsgCancelUnbondingDelegation\x1a<.cosmos.staking.v1beta1.MsgCancelUnbondingDelegationResponse\x12h\n\x0cUpdateParams\x12\'.cosmos.staking.v1beta1.MsgUpdateParams\x1a/.cosmos.staking.v1beta1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xcd\x01\n\x1a\x63om.cosmos.staking.v1beta1B\x07TxProtoP\x01Z,github.com/cosmos/cosmos-sdk/x/staking/types\xa2\x02\x03\x43SX\xaa\x02\x16\x43osmos.Staking.V1beta1\xca\x02\x16\x43osmos\\Staking\\V1beta1\xe2\x02\"Cosmos\\Staking\\V1beta1\\GPBMetadata\xea\x02\x18\x43osmos::Staking::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.cosmos.staking.v1beta1B\007TxProtoP\001Z,github.com/cosmos/cosmos-sdk/x/staking/types\242\002\003CSX\252\002\026Cosmos.Staking.V1beta1\312\002\026Cosmos\\Staking\\V1beta1\342\002\"Cosmos\\Staking\\V1beta1\\GPBMetadata\352\002\030Cosmos::Staking::V1beta1'
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['description']._loaded_options = None
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['description']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['commission']._loaded_options = None
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['commission']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['min_self_delegation']._loaded_options = None
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['min_self_delegation']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int\250\347\260*\001'
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['delegator_address']._serialized_options = b'\030\001\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['pubkey']._loaded_options = None
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['pubkey']._serialized_options = b'\312\264-\024cosmos.crypto.PubKey'
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['value']._loaded_options = None
  _globals['_MSGCREATEVALIDATOR'].fields_by_name['value']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCREATEVALIDATOR']._loaded_options = None
  _globals['_MSGCREATEVALIDATOR']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021validator_address\212\347\260*\035cosmos-sdk/MsgCreateValidator'
  _globals['_MSGEDITVALIDATOR'].fields_by_name['description']._loaded_options = None
  _globals['_MSGEDITVALIDATOR'].fields_by_name['description']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGEDITVALIDATOR'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGEDITVALIDATOR'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGEDITVALIDATOR'].fields_by_name['commission_rate']._loaded_options = None
  _globals['_MSGEDITVALIDATOR'].fields_by_name['commission_rate']._serialized_options = b'\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_MSGEDITVALIDATOR'].fields_by_name['min_self_delegation']._loaded_options = None
  _globals['_MSGEDITVALIDATOR'].fields_by_name['min_self_delegation']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_MSGEDITVALIDATOR']._loaded_options = None
  _globals['_MSGEDITVALIDATOR']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021validator_address\212\347\260*\033cosmos-sdk/MsgEditValidator'
  _globals['_MSGDELEGATE'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGDELEGATE'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGDELEGATE'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGDELEGATE'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGDELEGATE'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGDELEGATE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGDELEGATE']._loaded_options = None
  _globals['_MSGDELEGATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021delegator_address\212\347\260*\026cosmos-sdk/MsgDelegate'
  _globals['_MSGTRANSFERDELEGATION'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGTRANSFERDELEGATION'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGTRANSFERDELEGATION'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGTRANSFERDELEGATION'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGTRANSFERDELEGATION'].fields_by_name['receiver_address']._loaded_options = None
  _globals['_MSGTRANSFERDELEGATION'].fields_by_name['receiver_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGTRANSFERDELEGATION'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGTRANSFERDELEGATION'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGTRANSFERDELEGATION']._loaded_options = None
  _globals['_MSGTRANSFERDELEGATION']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021delegator_address\212\347\260* cosmos-sdk/MsgTransferDelegation'
  _globals['_MSGBEGINREDELEGATE'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGBEGINREDELEGATE'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGBEGINREDELEGATE'].fields_by_name['validator_src_address']._loaded_options = None
  _globals['_MSGBEGINREDELEGATE'].fields_by_name['validator_src_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGBEGINREDELEGATE'].fields_by_name['validator_dst_address']._loaded_options = None
  _globals['_MSGBEGINREDELEGATE'].fields_by_name['validator_dst_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGBEGINREDELEGATE'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGBEGINREDELEGATE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGBEGINREDELEGATE']._loaded_options = None
  _globals['_MSGBEGINREDELEGATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021delegator_address\212\347\260*\035cosmos-sdk/MsgBeginRedelegate'
  _globals['_MSGBEGINREDELEGATERESPONSE'].fields_by_name['completion_time']._loaded_options = None
  _globals['_MSGBEGINREDELEGATERESPONSE'].fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_MSGUNDELEGATE'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGUNDELEGATE'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUNDELEGATE'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGUNDELEGATE'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGUNDELEGATE'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGUNDELEGATE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUNDELEGATE']._loaded_options = None
  _globals['_MSGUNDELEGATE']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021delegator_address\212\347\260*\030cosmos-sdk/MsgUndelegate'
  _globals['_MSGUNDELEGATERESPONSE'].fields_by_name['completion_time']._loaded_options = None
  _globals['_MSGUNDELEGATERESPONSE'].fields_by_name['completion_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_MSGUNDELEGATERESPONSE'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGUNDELEGATERESPONSE'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCANCELUNBONDINGDELEGATION'].fields_by_name['delegator_address']._loaded_options = None
  _globals['_MSGCANCELUNBONDINGDELEGATION'].fields_by_name['delegator_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCANCELUNBONDINGDELEGATION'].fields_by_name['validator_address']._loaded_options = None
  _globals['_MSGCANCELUNBONDINGDELEGATION'].fields_by_name['validator_address']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_MSGCANCELUNBONDINGDELEGATION'].fields_by_name['amount']._loaded_options = None
  _globals['_MSGCANCELUNBONDINGDELEGATION'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCANCELUNBONDINGDELEGATION']._loaded_options = None
  _globals['_MSGCANCELUNBONDINGDELEGATION']._serialized_options = b'\210\240\037\000\350\240\037\000\202\347\260*\021delegator_address\212\347\260*\'cosmos-sdk/MsgCancelUnbondingDelegation'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*$cosmos-sdk/x/staking/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGCREATEVALIDATOR']._serialized_start=283
  _globals['_MSGCREATEVALIDATOR']._serialized_end=918
  _globals['_MSGCREATEVALIDATORRESPONSE']._serialized_start=920
  _globals['_MSGCREATEVALIDATORRESPONSE']._serialized_end=948
  _globals['_MSGEDITVALIDATOR']._serialized_start=951
  _globals['_MSGEDITVALIDATOR']._serialized_end=1372
  _globals['_MSGEDITVALIDATORRESPONSE']._serialized_start=1374
  _globals['_MSGEDITVALIDATORRESPONSE']._serialized_end=1400
  _globals['_MSGDELEGATE']._serialized_start=1403
  _globals['_MSGDELEGATE']._serialized_end=1688
  _globals['_MSGDELEGATERESPONSE']._serialized_start=1690
  _globals['_MSGDELEGATERESPONSE']._serialized_end=1711
  _globals['_MSGTRANSFERDELEGATION']._serialized_start=1714
  _globals['_MSGTRANSFERDELEGATION']._serialized_end=2088
  _globals['_MSGTRANSFERDELEGATIONRESPONSE']._serialized_start=2090
  _globals['_MSGTRANSFERDELEGATIONRESPONSE']._serialized_end=2121
  _globals['_MSGBEGINREDELEGATE']._serialized_start=2124
  _globals['_MSGBEGINREDELEGATE']._serialized_end=2517
  _globals['_MSGBEGINREDELEGATERESPONSE']._serialized_start=2519
  _globals['_MSGBEGINREDELEGATERESPONSE']._serialized_end=2631
  _globals['_MSGUNDELEGATE']._serialized_start=2634
  _globals['_MSGUNDELEGATE']._serialized_end=2923
  _globals['_MSGUNDELEGATERESPONSE']._serialized_start=2926
  _globals['_MSGUNDELEGATERESPONSE']._serialized_end=3095
  _globals['_MSGCANCELUNBONDINGDELEGATION']._serialized_start=3098
  _globals['_MSGCANCELUNBONDINGDELEGATION']._serialized_end=3458
  _globals['_MSGCANCELUNBONDINGDELEGATIONRESPONSE']._serialized_start=3460
  _globals['_MSGCANCELUNBONDINGDELEGATIONRESPONSE']._serialized_end=3498
  _globals['_MSGUPDATEPARAMS']._serialized_start=3501
  _globals['_MSGUPDATEPARAMS']._serialized_end=3698
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=3700
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=3725
  _globals['_MSG']._serialized_start=3728
  _globals['_MSG']._serialized_end=4649
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/applications/transfer/v1/authz.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ibc/applications/transfer/v1/authz.proto\x12\x1cibc.applications.transfer.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x91\x02\n\nAllocation\x12\x1f\n\x0bsource_port\x18\x01 \x01(\tR\nsourcePort\x12%\n\x0esource_channel\x18\x02 \x01(\tR\rsourceChannel\x12l\n\x0bspend_limit\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\nspendLimit\x12\x1d\n\nallow_list\x18\x04 \x03(\tR\tallowList\x12.\n\x13\x61llowed_packet_data\x18\x05 \x03(\tR\x11\x61llowedPacketData\"\x91\x01\n\x15TransferAuthorization\x12P\n\x0b\x61llocations\x18\x01 \x03(\x0b\x32(.ibc.applications.transfer.v1.AllocationB\x04\xc8\xde\x1f\x00R\x0b\x61llocations:&\xca\xb4-\"cosmos.authz.v1beta1.AuthorizationB\xfa\x01\n com.ibc.applications.transfer.v1B\nAuthzProtoP\x01Z7github.com/cosmos/ibc-go/v8/modules/apps/transfer/types\xa2\x02\x03IAT\xaa\x02\x1cIbc.Applications.Transfer.V1\xca\x02\x1cIbc\\Applications\\Transfer\\V1\xe2\x02(Ibc\\Applications\\Transfer\\V1\\GPBMetadata\xea\x02\x1fIbc::Applications::Transfer::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.applications.transfer.v1.authz_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.ibc.applications.transfer.v1B\nAuthzProtoP\001Z7github.com/cosmos/ibc-go/v8/modules/apps/transfer/types\242\002\003IAT\252\002\034Ibc.Applications.Transfer.V1\312\002\034Ibc\\Applications\\Transfer\\V1\342\002(Ibc\\Applications\\Transfer\\V1\\GPBMetadata\352\002\037Ibc::Applications::Transfer::V1'
  _globals['_ALLOCATION'].fields_by_name['spend_limit']._loaded_options = None
  _globals['_ALLOCATION'].fields_by_name['spend_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_TRANSFERAUTHORIZATION'].fields_by_name['allocations']._loaded_options = None
  _globals['_TRANSFERAUTHORIZATION'].fields_by_name['allocations']._serialized_options = b'\310\336\037\000'
  _globals['_TRANSFERAUTHORIZATION']._loaded_options = None
  _globals['_TRANSFERAUTHORIZATION']._serialized_options = b'\312\264-\"cosmos.authz.v1beta1.Authorization'
  _globals['_ALLOCATION']._serialized_start=156
  _globals['_ALLOCATION']._serialized_end=429
  _globals['_TRANSFERAUTHORIZATION']._serialized_start=432
  _globals['_TRANSFERAUTHORIZATION']._serialized_end=577
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/reflection/v2alpha1/reflection.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0cosmos/base/reflection/v2alpha1/reflection.proto\x12\x1f\x63osmos.base.reflection.v2alpha1\x1a\x1cgoogle/api/annotations.proto\"\xe7\x03\n\rAppDescriptor\x12\x46\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptorR\x05\x61uthn\x12\x46\n\x05\x63hain\x18\x02 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptorR\x05\x63hain\x12\x46\n\x05\x63odec\x18\x03 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptorR\x05\x63odec\x12^\n\rconfiguration\x18\x04 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptorR\rconfiguration\x12_\n\x0equery_services\x18\x05 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptorR\rqueryServices\x12=\n\x02tx\x18\x06 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptorR\x02tx\"n\n\x0cTxDescriptor\x12\x1a\n\x08\x66ullname\x18\x01 \x01(\tR\x08\x66ullname\x12\x42\n\x04msgs\x18\x02 \x03(\x0b\x32..cosmos.base.reflection.v2alpha1.MsgDescriptorR\x04msgs\"h\n\x0f\x41uthnDescriptor\x12U\n\nsign_modes\x18\x01 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.SigningModeDescriptorR\tsignModes\"\x91\x01\n\x15SigningModeDescriptor\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06number\x18\x02 \x01(\x05R\x06number\x12L\n#authn_info_provider_method_fullname\x18\x03 \x01(\tR\x1f\x61uthnInfoProviderMethodFullname\"!\n\x0f\x43hainDescriptor\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"g\n\x0f\x43odecDescriptor\x12T\n\ninterfaces\x18\x01 \x03(\x0b\x32\x34.cosmos.base.reflection.v2alpha1.InterfaceDescriptorR\ninterfaces\"\xb2\x02\n\x13InterfaceDescriptor\x12\x1a\n\x08\x66ullname\x18\x01 \x01(\tR\x08\x66ullname\x12\x86\x01\n\x1cinterface_accepting_messages\x18\x02 \x03(\x0b\x32\x44.cosmos.base.reflection.v2alpha1.InterfaceAcceptingMessageDescriptorR\x1ainterfaceAcceptingMessages\x12v\n\x16interface_implementers\x18\x03 \x03(\x0b\x32?.cosmos.base.reflection.v2alpha1.InterfaceImplementerDescriptorR\x15interfaceImplementers\"W\n\x1eInterfaceImplementerDescriptor\x12\x1a\n\x08\x66ullname\x18\x01 \x01(\tR\x08\x66ullname\x12\x19\n\x08type_url\x18\x02 \x01(\tR\x07typeUrl\"w\n#InterfaceAcceptingMessageDescriptor\x12\x1a\n\x08\x66ullname\x18\x01 \x01(\tR\x08\x66ullname\x12\x34\n\x16\x66ield_descriptor_names\x18\x02 \x03(\tR\x14\x66ieldDescriptorNames\"\\\n\x17\x43onfigurationDescriptor\x12\x41\n\x1d\x62\x65\x63h32_account_address_prefix\x18\x01 \x01(\tR\x1a\x62\x65\x63h32AccountAddressPrefix\"1\n\rMsgDescriptor\x12 \n\x0cmsg_type_url\x18\x01 \x01(\tR\nmsgTypeUrl\"\x1b\n\x19GetAuthnDescriptorRequest\"d\n\x1aGetAuthnDescriptorResponse\x12\x46\n\x05\x61uthn\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.AuthnDescriptorR\x05\x61uthn\"\x1b\n\x19GetChainDescriptorRequest\"d\n\x1aGetChainDescriptorResponse\x12\x46\n\x05\x63hain\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.ChainDescriptorR\x05\x63hain\"\x1b\n\x19GetCodecDescriptorRequest\"d\n\x1aGetCodecDescriptorResponse\x12\x46\n\x05\x63odec\x18\x01 \x01(\x0b\x32\x30.cosmos.base.reflection.v2alpha1.CodecDescriptorR\x05\x63odec\"#\n!GetConfigurationDescriptorRequest\"v\n\"GetConfigurationDescriptorResponse\x12P\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.ConfigurationDescriptorR\x06\x63onfig\"#\n!GetQueryServicesDescriptorRequest\"x\n\"GetQueryServicesDescriptorResponse\x12R\n\x07queries\x18\x01 \x01(\x0b\x32\x38.cosmos.base.reflection.v2alpha1.QueryServicesDescriptorR\x07queries\"\x18\n\x16GetTxDescriptorRequest\"X\n\x17GetTxDescriptorResponse\x12=\n\x02tx\x18\x01 \x01(\x0b\x32-.cosmos.base.reflection.v2alpha1.TxDescriptorR\x02tx\"y\n\x17QueryServicesDescriptor\x12^\n\x0equery_services\x18\x01 \x03(\x0b\x32\x37.cosmos.base.reflection.v2alpha1.QueryServiceDescriptorR\rqueryServices\"\xa3\x01\n\x16QueryServiceDescriptor\x12\x1a\n\x08\x66ullname\x18\x01 \x01(\tR\x08\x66ullname\x12\x1b\n\tis_module\x18\x02 \x01(\x08R\x08isModule\x12P\n\x07methods\x18\x03 \x03(\x0b\x32\x36.cosmos.base.reflection.v2alpha1.QueryMethodDescriptorR\x07methods\"S\n\x15QueryMethodDescriptor\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12&\n\x0f\x66ull_query_path\x18\x02 \x01(\tR\rfullQueryPath2\xa7\n\n\x11ReflectionService\x12\xcb\x01\n\x12GetAuthnDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetAuthnDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/authn\x12\xcb\x01\n\x12GetChainDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetChainDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetChainDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/chain\x12\xcb\x01\n\x12GetCodecDescriptor\x12:.cosmos.base.reflection.v2alpha1.GetCodecDescriptorRequest\x1a;.cosmos.base.reflection.v2alpha1.GetCodecDescriptorResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/reflection/v1beta1/app_descriptor/codec\x12\xeb\x01\n\x1aGetConfigurationDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetConfigurationDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/configuration\x12\xec\x01\n\x1aGetQueryServicesDescriptor\x12\x42.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorRequest\x1a\x43.cosmos.base.reflection.v2alpha1.GetQueryServicesDescriptorResponse\"E\x82\xd3\xe4\x93\x02?\x12=/cosmos/base/reflection/v1beta1/app_descriptor/query_services\x12\xca\x01\n\x0fGetTxDescriptor\x12\x37.cosmos.base.reflection.v2alpha1.GetTxDescriptorRequest\x1a\x38.cosmos.base.reflection.v2alpha1.GetTxDescriptorResponse\"D\x82\xd3\xe4\x93\x02>\x12</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptorB\x93\x02\n#com.cosmos.base.reflection.v2alpha1B\x0fReflectionProtoP\x01Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1\xa2\x02\x03\x43\x42R\xaa\x02\x1f\x43osmos.Base.Reflection.V2alpha1\xca\x02\x1f\x43osmos\\Base\\Reflection\\V2alpha1\xe2\x02+Cosmos\\Base\\Reflection\\V2alpha1\\GPBMetadata\xea\x02\"Cosmos::Base::Reflection::V2alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.base.reflection.v2alpha1.reflection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.cosmos.base.reflection.v2alpha1B\017ReflectionProtoP\001Z<github.com/cosmos/cosmos-sdk/server/grpc/reflection/v2alpha1\242\002\003CBR\252\002\037Cosmos.Base.Reflection.V2alpha1\312\002\037Cosmos\\Base\\Reflection\\V2alpha1\342\002+Cosmos\\Base\\Reflection\\V2alpha1\\GPBMetadata\352\002\"Cosmos::Base::Reflection::V2alpha1'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetAuthnDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetAuthnDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/authn'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetChainDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetChainDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/chain'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetCodecDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetCodecDescriptor']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/reflection/v1beta1/app_descriptor/codec'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetConfigurationDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetConfigurationDescriptor']._serialized_options = b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/configuration'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetQueryServicesDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetQueryServicesDescriptor']._serialized_options = b'\202\323\344\223\002?\022=/cosmos/base/reflection/v1beta1/app_descriptor/query_services'
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetTxDescriptor']._loaded_options = None
  _globals['_REFLECTIONSERVICE'].methods_by_name['GetTxDescriptor']._serialized_options = b'\202\323\344\223\002>\022</cosmos/base/reflection/v1beta1/app_descriptor/tx_descriptor'
  _globals['_APPDESCRIPTOR']._serialized_start=116
  _globals['_APPDESCRIPTOR']._serialized_end=603
  _globals['_TXDESCRIPTOR']._serialized_start=605
  _globals['_TXDESCRIPTOR']._serialized_end=715
  _globals['_AUTHNDESCRIPTOR']._serialized_start=717
  _globals['_AUTHNDESCRIPTOR']._serialized_end=821
  _globals['_SIGNINGMODEDESCRIPTOR']._serialized_start=824
  _globals['_SIGNINGMODEDESCRIPTOR']._serialized_end=969
  _globals['_CHAINDESCRIPTOR']._serialized_start=971
  _globals['_CHAINDESCRIPTOR']._serialized_end=1004
  _globals['_CODECDESCRIPTOR']._serialized_start=1006
  _globals['_CODECDESCRIPTOR']._serialized_end=1109
  _globals['_INTERFACEDESCRIPTOR']._serialized_start=1112
  _globals['_INTERFACEDESCRIPTOR']._serialized_end=1418
  _globals['_INTERFACEIMPLEMENTERDESCRIPTOR']._serialized_start=1420
  _globals['_INTERFACEIMPLEMENTERDESCRIPTOR']._serialized_end=1507
  _globals['_INTERFACEACCEPTINGMESSAGEDESCRIPTOR']._serialized_start=1509
  _globals['_INTERFACEACCEPTINGMESSAGEDESCRIPTOR']._serialized_end=1628
  _globals['_CONFIGURATIONDESCRIPTOR']._serialized_start=1630
  _globals['_CONFIGURATIONDESCRIPTOR']._serialized_end=1722
  _globals['_MSGDESCRIPTOR']._serialized_start=1724
  _globals['_MSGDESCRIPTOR']._serialized_end=1773
  _globals['_GETAUTHNDESCRIPTORREQUEST']._serialized_start=1775
  _globals['_GETAUTHNDESCRIPTORREQUEST']._serialized_end=1802
  _globals['_GETAUTHNDESCRIPTORRESPONSE']._serialized_start=1804
  _globals['_GETAUTHNDESCRIPTORRESPONSE']._serialized_end=1904
  _globals['_GETCHAINDESCRIPTORREQUEST']._serialized_start=1906
  _globals['_GETCHAINDESCRIPTORREQUEST']._serialized_end=1933
  _globals['_GETCHAINDESCRIPTORRESPONSE']._serialized_start=1935
  _globals['_GETCHAINDESCRIPTORRESPONSE']._serialized_end=2035
  _globals['_GETCODECDESCRIPTORREQUEST']._serialized_start=2037
  _globals['_GETCODECDESCRIPTORREQUEST']._serialized_end=2064
  _globals['_GETCODECDESCRIPTORRESPONSE']._serialized_start=2066
  _globals['_GETCODECDESCRIPTORRESPONSE']._serialized_end=2166
  _globals['_GETCONFIGURATIONDESCRIPTORREQUEST']._serialized_start=2168
  _globals['_GETCONFIGURATIONDESCRIPTORREQUEST']._serialized_end=2203
  _globals['_GETCONFIGURATIONDESCRIPTORRESPONSE']._serialized_start=2205
  _globals['_GETCONFIGURATIONDESCRIPTORRESPONSE']._serialized_end=2323
  _globals['_GETQUERYSERVICESDESCRIPTORREQUEST']._serialized_start=2325
  _globals['_GETQUERYSERVICESDESCRIPTORREQUEST']._serialized_end=2360
  _globals['_GETQUERYSERVICESDESCRIPTORRESPONSE']._serialized_start=2362
  _globals['_GETQUERYSERVICESDESCRIPTORRESPONSE']._serialized_end=2482
  _globals['_GETTXDESCRIPTORREQUEST']._serialized_start=2484
  _globals['_GETTXDESCRIPTORREQUEST']._serialized_end=2508
  _globals['_GETTXDESCRIPTORRESPONSE']._serialized_start=2510
  _globals['_GETTXDESCRIPTORRESPONSE']._serialized_end=2598
  _globals['_QUERYSERVICESDESCRIPTOR']._serialized_start=2600
  _globals['_QUERYSERVICESDESCRIPTOR']._serialized_end=2721
  _globals['_QUERYSERVICEDESCRIPTOR']._serialized_start=2724
  _globals['_QUERYSERVICEDESCRIPTOR']._serialized_end=2887
  _globals['_QUERYMETHODDESCRIPTOR']._serialized_start=2889
  _globals['_QUERYMETHODDESCRIPTOR']._serialized_end=2972
  _globals['_REFLECTIONSERVICE']._serialized_start=2975
  _globals['_REFLECTIONSERVICE']._serialized_end=4294
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/pruning/v1/pruning.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cometbft/services/pruning/v1/pruning.proto\x12\x1c\x63ometbft.services.pruning.v1\"5\n\x1bSetBlockRetainHeightRequest\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\"\x1e\n\x1cSetBlockRetainHeightResponse\"\x1d\n\x1bGetBlockRetainHeightRequest\"\x8d\x01\n\x1cGetBlockRetainHeightResponse\x12*\n\x11\x61pp_retain_height\x18\x01 \x01(\x04R\x0f\x61ppRetainHeight\x12\x41\n\x1dpruning_service_retain_height\x18\x02 \x01(\x04R\x1apruningServiceRetainHeight\"<\n\"SetBlockResultsRetainHeightRequest\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\"%\n#SetBlockResultsRetainHeightResponse\"$\n\"GetBlockResultsRetainHeightRequest\"h\n#GetBlockResultsRetainHeightResponse\x12\x41\n\x1dpruning_service_retain_height\x18\x01 \x01(\x04R\x1apruningServiceRetainHeight\"9\n\x1fSetTxIndexerRetainHeightRequest\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\"\"\n SetTxIndexerRetainHeightResponse\"!\n\x1fGetTxIndexerRetainHeightRequest\":\n GetTxIndexerRetainHeightResponse\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\"<\n\"SetBlockIndexerRetainHeightRequest\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06height\"%\n#SetBlockIndexerRetainHeightResponse\"$\n\"GetBlockIndexerRetainHeightRequest\"=\n#GetBlockIndexerRetainHeightResponse\x12\x16\n\x06height\x18\x01 \x01(\x04R\x06heightB\xc3\x01\n com.cometbft.services.pruning.v1B\x0cPruningProtoP\x01\xa2\x02\x03\x43SP\xaa\x02\x1c\x43ometbft.Services.Pruning.V1\xca\x02\x1c\x43ometbft\\Services\\Pruning\\V1\xe2\x02(Cometbft\\Services\\Pruning\\V1\\GPBMetadata\xea\x02\x1f\x43ometbft::Services::Pruning::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.pruning.v1.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.cometbft.services.pruning.v1B\014PruningProtoP\001\242\002\003CSP\252\002\034Cometbft.Services.Pruning.V1\312\002\034Cometbft\\Services\\Pruning\\V1\342\002(Cometbft\\Services\\Pruning\\V1\\GPBMetadata\352\002\037Cometbft::Services::Pruning::V1'
  _globals['_SETBLOCKRETAINHEIGHTREQUEST']._serialized_start=76
  _globals['_SETBLOCKRETAINHEIGHTREQUEST']._serialized_end=129
  _globals['_SETBLOCKRETAINHEIGHTRESPONSE']._serialized_start=131
  _globals['_SETBLOCKRETAINHEIGHTRESPONSE']._serialized_end=161
  _globals['_GETBLOCKRETAINHEIGHTREQUEST']._serialized_start=163
  _globals['_GETBLOCKRETAINHEIGHTREQUEST']._serialized_end=192
  _globals['_GETBLOCKRETAINHEIGHTRESPONSE']._serialized_start=195
  _globals['_GETBLOCKRETAINHEIGHTRESPONSE']._serialized_end=336
  _globals['_SETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_start=338
  _globals['_SETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_end=398
  _globals['_SETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_start=400
  _globals['_SETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_end=437
  _globals['_GETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_start=439
  _globals['_GETBLOCKRESULTSRETAINHEIGHTREQUEST']._serialized_end=475
  _globals['_GETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_start=477
  _globals['_GETBLOCKRESULTSRETAINHEIGHTRESPONSE']._serialized_end=581
  _globals['_SETTXINDEXERRETAINHEIGHTREQUEST']._serialized_start=583
  _globals['_SETTXINDEXERRETAINHEIGHTREQUEST']._serialized_end=640
  _globals['_SETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_start=642
  _globals['_SETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_end=676
  _globals['_GETTXINDEXERRETAINHEIGHTREQUEST']._serialized_start=678
  _globals['_GETTXINDEXERRETAINHEIGHTREQUEST']._serialized_end=711
  _globals['_GETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_start=713
  _globals['_GETTXINDEXERRETAINHEIGHTRESPONSE']._serialized_end=771
  _globals['_SETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_start=773
  _globals['_SETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_end=833
  _globals['_SETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_start=835
  _globals['_SETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_end=872
  _globals['_GETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_start=874
  _globals['_GETBLOCKINDEXERRETAINHEIGHTREQUEST']._serialized_end=910
  _globals['_GETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_start=912
  _globals['_GETBLOCKINDEXERRETAINHEIGHTRESPONSE']._serialized_end=973
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.cosmos.autocli.v1 import query_pb2 as cosmos_dot_autocli_dot_v1_dot_query__pb2


class QueryStub(object):
    """RemoteInfoService provides clients with the information they need
    to build dynamically CLI clients for remote chains.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AppOptions = channel.unary_unary(
                '/cosmos.autocli.v1.Query/AppOptions',
                request_serializer=cosmos_dot_autocli_dot_v1_dot_query__pb2.AppOptionsRequest.SerializeToString,
                response_deserializer=cosmos_dot_autocli_dot_v1_dot_query__pb2.AppOptionsResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """RemoteInfoService provides clients with the information they need
    to build dynamically CLI clients for remote chains.
    """

    def AppOptions(self, request, context):
        """AppOptions returns the autocli options for all of the modules in an app.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AppOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.AppOptions,
                    request_deserializer=cosmos_dot_autocli_dot_v1_dot_query__pb2.AppOptionsRequest.FromString,
                    response_serializer=cosmos_dot_autocli_dot_v1_dot_query__pb2.AppOptionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.autocli.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.autocli.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """RemoteInfoService provides clients with the information they need
    to build dynamically CLI clients for remote chains.
    """

    @staticmethod
    def AppOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.autocli.v1.Query/AppOptions',
            cosmos_dot_autocli_dot_v1_dot_query__pb2.AppOptionsRequest.SerializeToString,
            cosmos_dot_autocli_dot_v1_dot_query__pb2.AppOptionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from pyinjective.proto.injective.oracle.v1beta1 import genesis_pb2 as injective_dot_oracle_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/oracle/v1beta1/query.proto\x12\x18injective.oracle.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a&injective/oracle/v1beta1/genesis.proto\x1a\x14gogoproto/gogo.proto\"2\n\x15QueryPythPriceRequest\x12\x19\n\x08price_id\x18\x01 \x01(\tR\x07priceId\"c\n\x16QueryPythPriceResponse\x12I\n\x0bprice_state\x18\x01 \x01(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateR\npriceState\"\x14\n\x12QueryParamsRequest\"U\n\x13QueryParamsResponse\x12>\n\x06params\x18\x01 \x01(\x0b\x32 .injective.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x1a\n\x18QueryBandRelayersRequest\"7\n\x19QueryBandRelayersResponse\x12\x1a\n\x08relayers\x18\x01 \x03(\tR\x08relayers\"\x1d\n\x1bQueryBandPriceStatesRequest\"k\n\x1cQueryBandPriceStatesResponse\x12K\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceStateR\x0bpriceStates\" \n\x1eQueryBandIBCPriceStatesRequest\"n\n\x1fQueryBandIBCPriceStatesResponse\x12K\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.BandPriceStateR\x0bpriceStates\"\"\n QueryPriceFeedPriceStatesRequest\"p\n!QueryPriceFeedPriceStatesResponse\x12K\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PriceFeedStateR\x0bpriceStates\"!\n\x1fQueryCoinbasePriceStatesRequest\"s\n QueryCoinbasePriceStatesResponse\x12O\n\x0cprice_states\x18\x01 \x03(\x0b\x32,.injective.oracle.v1beta1.CoinbasePriceStateR\x0bpriceStates\"\x1d\n\x1bQueryPythPriceStatesRequest\"k\n\x1cQueryPythPriceStatesResponse\x12K\n\x0cprice_states\x18\x01 \x03(\x0b\x32(.injective.oracle.v1beta1.PythPriceStateR\x0bpriceStates\"\x1e\n\x1cQueryStorkPriceStatesRequest\"m\n\x1dQueryStorkPriceStatesResponse\x12L\n\x0cprice_states\x18\x01 \x03(\x0b\x32).injective.oracle.v1beta1.StorkPriceStateR\x0bpriceStates\"\x1d\n\x1bQueryStorkPublishersRequest\">\n\x1cQueryStorkPublishersResponse\x12\x1e\n\npublishers\x18\x01 \x03(\tR\npublishers\"T\n\x1eQueryProviderPriceStateRequest\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x16\n\x06symbol\x18\x02 \x01(\tR\x06symbol\"h\n\x1fQueryProviderPriceStateResponse\x12\x45\n\x0bprice_state\x18\x01 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateR\npriceState\"\x19\n\x17QueryModuleStateRequest\"X\n\x18QueryModuleStateResponse\x12<\n\x05state\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.GenesisStateR\x05state\"\x7f\n\"QueryHistoricalPriceRecordsRequest\x12<\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\x06oracle\x12\x1b\n\tsymbol_id\x18\x02 \x01(\tR\x08symbolId\"r\n#QueryHistoricalPriceRecordsResponse\x12K\n\rprice_records\x18\x01 \x03(\x0b\x32&.injective.oracle.v1beta1.PriceRecordsR\x0cpriceRecords\"\x8a\x01\n\x14OracleHistoryOptions\x12\x17\n\x07max_age\x18\x01 \x01(\x04R\x06maxAge\x12.\n\x13include_raw_history\x18\x02 \x01(\x08R\x11includeRawHistory\x12)\n\x10include_metadata\x18\x03 \x01(\x08R\x0fincludeMetadata\"\x8c\x02\n\x1cQueryOracleVolatilityRequest\x12\x41\n\tbase_info\x18\x01 \x01(\x0b\x32$.injective.oracle.v1beta1.OracleInfoR\x08\x62\x61seInfo\x12\x43\n\nquote_info\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.OracleInfoR\tquoteInfo\x12\x64\n\x16oracle_history_options\x18\x03 \x01(\x0b\x32..injective.oracle.v1beta1.OracleHistoryOptionsR\x14oracleHistoryOptions\"\x81\x02\n\x1dQueryOracleVolatilityResponse\x12?\n\nvolatility\x18\x01 \x01(\tB\x1f\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nvolatility\x12W\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatisticsR\x0fhistoryMetadata\x12\x46\n\x0braw_history\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecordR\nrawHistory\"!\n\x1fQueryOracleProvidersInfoRequest\"h\n QueryOracleProvidersInfoResponse\x12\x44\n\tproviders\x18\x01 \x03(\x0b\x32&.injective.oracle.v1beta1.ProviderInfoR\tproviders\">\n QueryOracleProviderPricesRequest\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\"r\n!QueryOracleProviderPricesResponse\x12M\n\rproviderState\x18\x01 \x03(\x0b\x32\'.injective.oracle.v1beta1.ProviderStateR\rproviderState\"\\\n\x0eScalingOptions\x12#\n\rbase_decimals\x18\x01 \x01(\rR\x0c\x62\x61seDecimals\x12%\n\x0equote_decimals\x18\x02 \x01(\rR\rquoteDecimals\"\xe3\x01\n\x17QueryOraclePriceRequest\x12\x45\n\x0boracle_type\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\x12\x12\n\x04\x62\x61se\x18\x02 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x03 \x01(\tR\x05quote\x12W\n\x0fscaling_options\x18\x04 \x01(\x0b\x32(.injective.oracle.v1beta1.ScalingOptionsB\x04\xc8\xde\x1f\x01R\x0escalingOptions\"\xe2\x03\n\x0ePricePairState\x12\x42\n\npair_price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tpairPrice\x12\x42\n\nbase_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\tbasePrice\x12\x44\n\x0bquote_price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\nquotePrice\x12W\n\x15\x62\x61se_cumulative_price\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x13\x62\x61seCumulativePrice\x12Y\n\x16quote_cumulative_price\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x14quoteCumulativePrice\x12%\n\x0e\x62\x61se_timestamp\x18\x06 \x01(\x03R\rbaseTimestamp\x12\'\n\x0fquote_timestamp\x18\x07 \x01(\x03R\x0equoteTimestamp\"n\n\x18QueryOraclePriceResponse\x12R\n\x10price_pair_state\x18\x01 \x01(\x0b\x32(.injective.oracle.v1beta1.PricePairStateR\x0epricePairState2\xcd\x18\n\x05Query\x12\x8f\x01\n\x06Params\x12,.injective.oracle.v1beta1.QueryParamsRequest\x1a-.injective.oracle.v1beta1.QueryParamsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /injective/oracle/v1beta1/params\x12\xa8\x01\n\x0c\x42\x61ndRelayers\x12\x32.injective.oracle.v1beta1.QueryBandRelayersRequest\x1a\x33.injective.oracle.v1beta1.QueryBandRelayersResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/injective/oracle/v1beta1/band_relayers\x12\xb5\x01\n\x0f\x42\x61ndPriceStates\x12\x35.injective.oracle.v1beta1.QueryBandPriceStatesRequest\x1a\x36.injective.oracle.v1beta1.QueryBandPriceStatesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/oracle/v1beta1/band_price_states\x12\xc2\x01\n\x12\x42\x61ndIBCPriceStates\x12\x38.injective.oracle.v1beta1.QueryBandIBCPriceStatesRequest\x1a\x39.injective.oracle.v1beta1.QueryBandIBCPriceStatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/oracle/v1beta1/band_ibc_price_states\x12\xc9\x01\n\x14PriceFeedPriceStates\x12:.injective.oracle.v1beta1.QueryPriceFeedPriceStatesRequest\x1a;.injective.oracle.v1beta1.QueryPriceFeedPriceStatesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/oracle/v1beta1/pricefeed_price_states\x12\xc5\x01\n\x13\x43oinbasePriceStates\x12\x39.injective.oracle.v1beta1.QueryCoinbasePriceStatesRequest\x1a:.injective.oracle.v1beta1.QueryCoinbasePriceStatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/oracle/v1beta1/coinbase_price_states\x12\xb5\x01\n\x0fPythPriceStates\x12\x35.injective.oracle.v1beta1.QueryPythPriceStatesRequest\x1a\x36.injective.oracle.v1beta1.QueryPythPriceStatesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/injective/oracle/v1beta1/pyth_price_states\x12\xb9\x01\n\x10StorkPriceStates\x12\x36.injective.oracle.v1beta1.QueryStorkPriceStatesRequest\x1a\x37.injective.oracle.v1beta1.QueryStorkPriceStatesResponse\"4\x82\xd3\xe4\x93\x02.\x12,/injective/oracle/v1beta1/stork_price_states\x12\xb4\x01\n\x0fStorkPublishers\x12\x35.injective.oracle.v1beta1.QueryStorkPublishersRequest\x1a\x36.injective.oracle.v1beta1.QueryStorkPublishersResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/oracle/v1beta1/stork_publishers\x12\xd5\x01\n\x12ProviderPriceState\x12\x38.injective.oracle.v1beta1.QueryProviderPriceStateRequest\x1a\x39.injective.oracle.v1beta1.QueryProviderPriceStateResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/injective/oracle/v1beta1/provider_price_state/{provider}/{symbol}\x12\xaa\x01\n\x11OracleModuleState\x12\x31.injective.oracle.v1beta1.QueryModuleStateRequest\x1a\x32.injective.oracle.v1beta1.QueryModuleStateResponse\".\x82\xd3\xe4\x93\x02(\x12&/injective/oracle/v1beta1/module_state\x12\xd1\x01\n\x16HistoricalPriceRecords\x12<.injective.oracle.v1beta1.QueryHistoricalPriceRecordsRequest\x1a=.injective.oracle.v1beta1.QueryHistoricalPriceRecordsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/oracle/v1beta1/historical_price_records\x12\xb1\x01\n\x10OracleVolatility\x12\x36.injective.oracle.v1beta1.QueryOracleVolatilityRequest\x1a\x37.injective.oracle.v1beta1.QueryOracleVolatilityResponse\",\x82\xd3\xe4\x93\x02&\x12$/injective/oracle/v1beta1/volatility\x12\xb9\x01\n\x13OracleProvidersInfo\x12\x39.injective.oracle.v1beta1.QueryOracleProvidersInfoRequest\x1a:.injective.oracle.v1beta1.QueryOracleProvidersInfoResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/oracle/v1beta1/providers\x12\xc2\x01\n\x14OracleProviderPrices\x12:.injective.oracle.v1beta1.QueryOracleProviderPricesRequest\x1a;.injective.oracle.v1beta1.QueryOracleProviderPricesResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/oracle/v1beta1/provider_prices\x12\x9d\x01\n\x0bOraclePrice\x12\x31.injective.oracle.v1beta1.QueryOraclePriceRequest\x1a\x32.injective.oracle.v1beta1.QueryOraclePriceResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/injective/oracle/v1beta1/price\x12\x9c\x01\n\tPythPrice\x12/.injective.oracle.v1beta1.QueryPythPriceRequest\x1a\x30.injective.oracle.v1beta1.QueryPythPriceResponse\",\x82\xd3\xe4\x93\x02&\x12$/injective/oracle/v1beta1/pyth_priceB\xfa\x01\n\x1c\x63om.injective.oracle.v1beta1B\nQueryProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\nQueryProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYORACLEVOLATILITYRESPONSE'].fields_by_name['volatility']._loaded_options = None
  _globals['_QUERYORACLEVOLATILITYRESPONSE'].fields_by_name['volatility']._serialized_options = b'\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERYORACLEPRICEREQUEST'].fields_by_name['scaling_options']._loaded_options = None
  _globals['_QUERYORACLEPRICEREQUEST'].fields_by_name['scaling_options']._serialized_options = b'\310\336\037\001'
  _globals['_PRICEPAIRSTATE'].fields_by_name['pair_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['pair_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICEPAIRSTATE'].fields_by_name['base_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['base_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICEPAIRSTATE'].fields_by_name['quote_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['quote_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICEPAIRSTATE'].fields_by_name['base_cumulative_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['base_cumulative_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICEPAIRSTATE'].fields_by_name['quote_cumulative_price']._loaded_options = None
  _globals['_PRICEPAIRSTATE'].fields_by_name['quote_cumulative_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\"\022 /injective/oracle/v1beta1/params'
  _globals['_QUERY'].methods_by_name['BandRelayers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BandRelayers']._serialized_options = b'\202\323\344\223\002)\022\'/injective/oracle/v1beta1/band_relayers'
  _globals['_QUERY'].methods_by_name['BandPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BandPriceStates']._serialized_options = b'\202\323\344\223\002-\022+/injective/oracle/v1beta1/band_price_states'
  _globals['_QUERY'].methods_by_name['BandIBCPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BandIBCPriceStates']._serialized_options = b'\202\323\344\223\0021\022//injective/oracle/v1beta1/band_ibc_price_states'
  _globals['_QUERY'].methods_by_name['PriceFeedPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PriceFeedPriceStates']._serialized_options = b'\202\323\344\223\0022\0220/injective/oracle/v1beta1/pricefeed_price_states'
  _globals['_QUERY'].methods_by_name['CoinbasePriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CoinbasePriceStates']._serialized_options = b'\202\323\344\223\0021\022//injective/oracle/v1beta1/coinbase_price_states'
  _globals['_QUERY'].methods_by_name['PythPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PythPriceStates']._serialized_options = b'\202\323\344\223\002-\022+/injective/oracle/v1beta1/pyth_price_states'
  _globals['_QUERY'].methods_by_name['StorkPriceStates']._loaded_options = None
  _globals['_QUERY'].methods_by_name['StorkPriceStates']._serialized_options = b'\202\323\344\223\002.\022,/injective/oracle/v1beta1/stork_price_states'
  _globals['_QUERY'].methods_by_name['StorkPublishers']._loaded_options = None
  _globals['_QUERY'].methods_by_name['StorkPublishers']._serialized_options = b'\202\323\344\223\002,\022*/injective/oracle/v1beta1/stork_publishers'
  _globals['_QUERY'].methods_by_name['ProviderPriceState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ProviderPriceState']._serialized_options = b'\202\323\344\223\002D\022B/injective/oracle/v1beta1/provider_price_state/{provider}/{symbol}'
  _globals['_QUERY'].methods_by_name['OracleModuleState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OracleModuleState']._serialized_options = b'\202\323\344\223\002(\022&/injective/oracle/v1beta1/module_state'
  _globals['_QUERY'].methods_by_name['HistoricalPriceRecords']._loaded_options = None
  _globals['_QUERY'].methods_by_name['HistoricalPriceRecords']._serialized_options = b'\202\323\344\223\0024\0222/injective/oracle/v1beta1/historical_price_records'
  _globals['_QUERY'].methods_by_name['OracleVolatility']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OracleVolatility']._serialized_options = b'\202\323\344\223\002&\022$/injective/oracle/v1beta1/volatility'
  _globals['_QUERY'].methods_by_name['OracleProvidersInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OracleProvidersInfo']._serialized_options = b'\202\323\344\223\002%\022#/injective/oracle/v1beta1/providers'
  _globals['_QUERY'].methods_by_name['OracleProviderPrices']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OracleProviderPrices']._serialized_options = b'\202\323\344\223\002+\022)/injective/oracle/v1beta1/provider_prices'
  _globals['_QUERY'].methods_by_name['OraclePrice']._loaded_options = None
  _globals['_QUERY'].methods_by_name['OraclePrice']._serialized_options = b'\202\323\344\223\002!\022\037/injective/oracle/v1beta1/price'
  _globals['_QUERY'].methods_by_name['PythPrice']._loaded_options = None
  _globals['_QUERY'].methods_by_name['PythPrice']._serialized_options = b'\202\323\344\223\002&\022$/injective/oracle/v1beta1/pyth_price'
  _globals['_QUERYPYTHPRICEREQUEST']._serialized_start=197
  _globals['_QUERYPYTHPRICEREQUEST']._serialized_end=247
  _globals['_QUERYPYTHPRICERESPONSE']._serialized_start=249
  _globals['_QUERYPYTHPRICERESPONSE']._serialized_end=348
  _globals['_QUERYPARAMSREQUEST']._serialized_start=350
  _globals['_QUERYPARAMSREQUEST']._serialized_end=370
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=372
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=457
  _globals['_QUERYBANDRELAYERSREQUEST']._serialized_start=459
  _globals['_QUERYBANDRELAYERSREQUEST']._serialized_end=485
  _globals['_QUERYBANDRELAYERSRESPONSE']._serialized_start=487
  _globals['_QUERYBANDRELAYERSRESPONSE']._serialized_end=542
  _globals['_QUERYBANDPRICESTATESREQUEST']._serialized_start=544
  _globals['_QUERYBANDPRICESTATESREQUEST']._serialized_end=573
  _globals['_QUERYBANDPRICESTATESRESPONSE']._serialized_start=575
  _globals['_QUERYBANDPRICESTATESRESPONSE']._serialized_end=682
  _globals['_QUERYBANDIBCPRICESTATESREQUEST']._serialized_start=684
  _globals['_QUERYBANDIBCPRICESTATESREQUEST']._serialized_end=716
  _globals['_QUERYBANDIBCPRICESTATESRESPONSE']._serialized_start=718
  _globals['_QUERYBANDIBCPRICESTATESRESPONSE']._serialized_end=828
  _globals['_QUERYPRICEFEEDPRICESTATESREQUEST']._serialized_start=830
  _globals['_QUERYPRICEFEEDPRICESTATESREQUEST']._serialized_end=864
  _globals['_QUERYPRICEFEEDPRICESTATESRESPONSE']._serialized_start=866
  _globals['_QUERYPRICEFEEDPRICESTATESRESPONSE']._serialized_end=978
  _globals['_QUERYCOINBASEPRICESTATESREQUEST']._serialized_start=980
  _globals['_QUERYCOINBASEPRICESTATESREQUEST']._serialized_end=1013
  _globals['_QUERYCOINBASEPRICESTATESRESPONSE']._serialized_start=1015
  _globals['_QUERYCOINBASEPRICESTATESRESPONSE']._serialized_end=1130
  _globals['_QUERYPYTHPRICESTATESREQUEST']._serialized_start=1132
  _globals['_QUERYPYTHPRICESTATESREQUEST']._serialized_end=1161
  _globals['_QUERYPYTHPRICESTATESRESPONSE']._serialized_start=1163
  _globals['_QUERYPYTHPRICESTATESRESPONSE']._serialized_end=1270
  _globals['_QUERYSTORKPRICESTATESREQUEST']._serialized_start=1272
  _globals['_QUERYSTORKPRICESTATESREQUEST']._serialized_end=1302
  _globals['_QUERYSTORKPRICESTATESRESPONSE']._serialized_start=1304
  _globals['_QUERYSTORKPRICESTATESRESPONSE']._serialized_end=1413
  _globals['_QUERYSTORKPUBLISHERSREQUEST']._serialized_start=1415
  _globals['_QUERYSTORKPUBLISHERSREQUEST']._serialized_end=1444
  _globals['_QUERYSTORKPUBLISHERSRESPONSE']._serialized_start=1446
  _globals['_QUERYSTORKPUBLISHERSRESPONSE']._serialized_end=1508
  _globals['_QUERYPROVIDERPRICESTATEREQUEST']._serialized_start=1510
  _globals['_QUERYPROVIDERPRICESTATEREQUEST']._serialized_end=1594
  _globals['_QUERYPROVIDERPRICESTATERESPONSE']._serialized_start=1596
  _globals['_QUERYPROVIDERPRICESTATERESPONSE']._serialized_end=1700
  _globals['_QUERYMODULESTATEREQUEST']._serialized_start=1702
  _globals['_QUERYMODULESTATEREQUEST']._serialized_end=1727
  _globals['_QUERYMODULESTATERESPONSE']._serialized_start=1729
  _globals['_QUERYMODULESTATERESPONSE']._serialized_end=1817
  _globals['_QUERYHISTORICALPRICERECORDSREQUEST']._serialized_start=1819
  _globals['_QUERYHISTORICALPRICERECORDSREQUEST']._serialized_end=1946
  _globals['_QUERYHISTORICALPRICERECORDSRESPONSE']._serialized_start=1948
  _globals['_QUERYHISTORICALPRICERECORDSRESPONSE']._serialized_end=2062
  _globals['_ORACLEHISTORYOPTIONS']._serialized_start=2065
  _globals['_ORACLEHISTORYOPTIONS']._serialized_end=2203
  _globals['_QUERYORACLEVOLATILITYREQUEST']._serialized_start=2206
  _globals['_QUERYORACLEVOLATILITYREQUEST']._serialized_end=2474
  _globals['_QUERYORACLEVOLATILITYRESPONSE']._serialized_start=2477
  _globals['_QUERYORACLEVOLATILITYRESPONSE']._serialized_end=2734
  _globals['_QUERYORACLEPROVIDERSINFOREQUEST']._serialized_start=2736
  _globals['_QUERYORACLEPROVIDERSINFOREQUEST']._serialized_end=2769
  _globals['_QUERYORACLEPROVIDERSINFORESPONSE']._serialized_start=2771
  _globals['_QUERYORACLEPROVIDERSINFORESPONSE']._serialized_end=2875
  _globals['_QUERYORACLEPROVIDERPRICESREQUEST']._serialized_start=2877
  _globals['_QUERYORACLEPROVIDERPRICESREQUEST']._serialized_end=2939
  _globals['_QUERYORACLEPROVIDERPRICESRESPONSE']._serialized_start=2941
  _globals['_QUERYORACLEPROVIDERPRICESRESPONSE']._serialized_end=3055
  _globals['_SCALINGOPTIONS']._serialized_start=3057
  _globals['_SCALINGOPTIONS']._serialized_end=3149
  _globals['_QUERYORACLEPRICEREQUEST']._serialized_start=3152
  _globals['_QUERYORACLEPRICEREQUEST']._serialized_end=3379
  _globals['_PRICEPAIRSTATE']._serialized_start=3382
  _globals['_PRICEPAIRSTATE']._serialized_end=3864
  _globals['_QUERYORACLEPRICERESPONSE']._serialized_start=3866
  _globals['_QUERYORACLEPRICERESPONSE']._serialized_end=3976
  _globals['_QUERY']._serialized_start=3979
  _globals['_QUERY']._serialized_end=7128
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/orm/query/v1alpha1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/orm/query/v1alpha1/query.proto\x12\x19\x63osmos.orm.query.v1alpha1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19google/protobuf/any.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\"\x84\x01\n\nGetRequest\x12!\n\x0cmessage_name\x18\x01 \x01(\tR\x0bmessageName\x12\x14\n\x05index\x18\x02 \x01(\tR\x05index\x12=\n\x06values\x18\x03 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueR\x06values\";\n\x0bGetResponse\x12,\n\x06result\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x06result\"\xee\x03\n\x0bListRequest\x12!\n\x0cmessage_name\x18\x01 \x01(\tR\x0bmessageName\x12\x14\n\x05index\x18\x02 \x01(\tR\x05index\x12G\n\x06prefix\x18\x03 \x01(\x0b\x32-.cosmos.orm.query.v1alpha1.ListRequest.PrefixH\x00R\x06prefix\x12\x44\n\x05range\x18\x04 \x01(\x0b\x32,.cosmos.orm.query.v1alpha1.ListRequest.RangeH\x00R\x05range\x12\x46\n\npagination\x18\x05 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\x1aG\n\x06Prefix\x12=\n\x06values\x18\x01 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueR\x06values\x1a}\n\x05Range\x12;\n\x05start\x18\x01 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueR\x05start\x12\x37\n\x03\x65nd\x18\x02 \x03(\x0b\x32%.cosmos.orm.query.v1alpha1.IndexValueR\x03\x65ndB\x07\n\x05query\"\x87\x01\n\x0cListResponse\x12.\n\x07results\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyR\x07results\x12G\n\npagination\x18\x05 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x8c\x02\n\nIndexValue\x12\x14\n\x04uint\x18\x01 \x01(\x04H\x00R\x04uint\x12\x12\n\x03int\x18\x02 \x01(\x03H\x00R\x03int\x12\x12\n\x03str\x18\x03 \x01(\tH\x00R\x03str\x12\x16\n\x05\x62ytes\x18\x04 \x01(\x0cH\x00R\x05\x62ytes\x12\x14\n\x04\x65num\x18\x05 \x01(\tH\x00R\x04\x65num\x12\x14\n\x04\x62ool\x18\x06 \x01(\x08H\x00R\x04\x62ool\x12:\n\ttimestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\ttimestamp\x12\x37\n\x08\x64uration\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x08\x64urationB\x07\n\x05value2\xb6\x01\n\x05Query\x12T\n\x03Get\x12%.cosmos.orm.query.v1alpha1.GetRequest\x1a&.cosmos.orm.query.v1alpha1.GetResponse\x12W\n\x04List\x12&.cosmos.orm.query.v1alpha1.ListRequest\x1a\'.cosmos.orm.query.v1alpha1.ListResponseB\xb2\x01\n\x1d\x63om.cosmos.orm.query.v1alpha1B\nQueryProtoP\x01\xa2\x02\x03\x43OQ\xaa\x02\x19\x43osmos.Orm.Query.V1alpha1\xca\x02\x19\x43osmos\\Orm\\Query\\V1alpha1\xe2\x02%Cosmos\\Orm\\Query\\V1alpha1\\GPBMetadata\xea\x02\x1c\x43osmos::Orm::Query::V1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.orm.query.v1alpha1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.cosmos.orm.query.v1alpha1B\nQueryProtoP\001\242\002\003COQ\252\002\031Cosmos.Orm.Query.V1alpha1\312\002\031Cosmos\\Orm\\Query\\V1alpha1\342\002%Cosmos\\Orm\\Query\\V1alpha1\\GPBMetadata\352\002\034Cosmos::Orm::Query::V1alpha1'
  _globals['_GETREQUEST']._serialized_start=205
  _globals['_GETREQUEST']._serialized_end=337
  _globals['_GETRESPONSE']._serialized_start=339
  _globals['_GETRESPONSE']._serialized_end=398
  _globals['_LISTREQUEST']._serialized_start=401
  _globals['_LISTREQUEST']._serialized_end=895
  _globals['_LISTREQUEST_PREFIX']._serialized_start=688
  _globals['_LISTREQUEST_PREFIX']._serialized_end=759
  _globals['_LISTREQUEST_RANGE']._serialized_start=761
  _globals['_LISTREQUEST_RANGE']._serialized_end=886
  _globals['_LISTRESPONSE']._serialized_start=898
  _globals['_LISTRESPONSE']._serialized_end=1033
  _globals['_INDEXVALUE']._serialized_start=1036
  _globals['_INDEXVALUE']._serialized_end=1304
  _globals['_QUERY']._serialized_start=1307
  _globals['_QUERY']._serialized_end=1489
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from pyinjective.proto.injective.tokenfactory.v1beta1 import authorityMetadata_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+injective/tokenfactory/v1beta1/events.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x36injective/tokenfactory/v1beta1/authorityMetadata.proto\"B\n\x10\x45ventCreateDenom\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\"x\n\tEventMint\x12\x16\n\x06minter\x18\x01 \x01(\tR\x06minter\x12\x37\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\x12\x1a\n\x08receiver\x18\x03 \x01(\tR\x08receiver\"y\n\tEventBurn\x12\x16\n\x06\x62urner\x18\x01 \x01(\tR\x06\x62urner\x12\x37\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\x12\x1b\n\tburn_from\x18\x03 \x01(\tR\x08\x62urnFrom\"T\n\x10\x45ventChangeAdmin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12*\n\x11new_admin_address\x18\x02 \x01(\tR\x0fnewAdminAddress\"n\n\x15\x45ventSetDenomMetadata\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12?\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00R\x08metadataB\x9f\x02\n\"com.injective.tokenfactory.v1beta1B\x0b\x45ventsProtoP\x01ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\xa2\x02\x03ITX\xaa\x02\x1eInjective.Tokenfactory.V1beta1\xca\x02\x1eInjective\\Tokenfactory\\V1beta1\xe2\x02*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\xea\x02 Injective::Tokenfactory::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.injective.tokenfactory.v1beta1B\013EventsProtoP\001ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\242\002\003ITX\252\002\036Injective.Tokenfactory.V1beta1\312\002\036Injective\\Tokenfactory\\V1beta1\342\002*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\352\002 Injective::Tokenfactory::V1beta1'
  _globals['_EVENTMINT'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTMINT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTBURN'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTBURN'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTSETDENOMMETADATA'].fields_by_name['metadata']._loaded_options = None
  _globals['_EVENTSETDENOMMETADATA'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTCREATEDENOM']._serialized_start=221
  _globals['_EVENTCREATEDENOM']._serialized_end=287
  _globals['_EVENTMINT']._serialized_start=289
  _globals['_EVENTMINT']._serialized_end=409
  _globals['_EVENTBURN']._serialized_start=411
  _globals['_EVENTBURN']._serialized_end=532
  _globals['_EVENTCHANGEADMIN']._serialized_start=534
  _globals['_EVENTCHANGEADMIN']._serialized_end=618
  _globals['_EVENTSETDENOMMETADATA']._serialized_start=620
  _globals['_EVENTSETDENOMMETADATA']._serialized_end=730
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dinjective/evm/v1/events.proto\x12\x10injective.evm.v1\"\xcb\x01\n\x0f\x45ventEthereumTx\x12\x16\n\x06\x61mount\x18\x01 \x01(\tR\x06\x61mount\x12\x19\n\x08\x65th_hash\x18\x02 \x01(\tR\x07\x65thHash\x12\x14\n\x05index\x18\x03 \x01(\tR\x05index\x12\x19\n\x08gas_used\x18\x04 \x01(\tR\x07gasUsed\x12\x12\n\x04hash\x18\x05 \x01(\tR\x04hash\x12\x1c\n\trecipient\x18\x06 \x01(\tR\trecipient\x12\"\n\reth_tx_failed\x18\x07 \x01(\tR\x0b\x65thTxFailed\"%\n\nEventTxLog\x12\x17\n\x07tx_logs\x18\x01 \x03(\tR\x06txLogs\"W\n\x0c\x45ventMessage\x12\x16\n\x06module\x18\x01 \x01(\tR\x06module\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12\x17\n\x07tx_type\x18\x03 \x01(\tR\x06txType\"\'\n\x0f\x45ventBlockBloom\x12\x14\n\x05\x62loom\x18\x01 \x01(\tR\x05\x62loomB\xd0\x01\n\x14\x63om.injective.evm.v1B\x0b\x45ventsProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\013EventsProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_EVENTETHEREUMTX']._serialized_start=52
  _globals['_EVENTETHEREUMTX']._serialized_end=255
  _globals['_EVENTTXLOG']._serialized_start=257
  _globals['_EVENTTXLOG']._serialized_end=294
  _globals['_EVENTMESSAGE']._serialized_start=296
  _globals['_EVENTMESSAGE']._serialized_end=383
  _globals['_EVENTBLOCKBLOOM']._serialized_start=385
  _globals['_EVENTBLOCKBLOOM']._serialized_end=424
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, List, Optional

from grpc.aio import Channel

from pyinjective.client.model.pagination import PaginationOption
from pyinjective.core.network import CookieAssistant
from pyinjective.proto.exchange import (
    injective_accounts_rpc_pb2 as exchange_accounts_pb,
    injective_accounts_rpc_pb2_grpc as exchange_accounts_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class IndexerGrpcAccountApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = self._stub = exchange_accounts_grpc.InjectiveAccountsRPCStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_portfolio(self, account_address: str) -> Dict[str, Any]:
        request = exchange_accounts_pb.PortfolioRequest(account_address=account_address)
        response = await self._execute_call(call=self._stub.Portfolio, request=request)

        return response

    async def fetch_order_states(
        self,
        spot_order_hashes: Optional[List[str]] = None,
        derivative_order_hashes: Optional[List[str]] = None,
    ) -> Dict[str, Any]:
        spot_order_hashes = spot_order_hashes or []
        derivative_order_hashes = derivative_order_hashes or []

        request = exchange_accounts_pb.OrderStatesRequest(
            spot_order_hashes=spot_order_hashes, derivative_order_hashes=derivative_order_hashes
        )
        response = await self._execute_call(call=self._stub.OrderStates, request=request)

        return response

    async def fetch_subaccounts_list(self, address: str) -> Dict[str, Any]:
        request = exchange_accounts_pb.SubaccountsListRequest(account_address=address)
        response = await self._execute_call(call=self._stub.SubaccountsList, request=request)

        return response

    async def fetch_subaccount_balances_list(
        self, subaccount_id: str, denoms: Optional[List[str]] = None
    ) -> Dict[str, Any]:
        request = exchange_accounts_pb.SubaccountBalancesListRequest(
            subaccount_id=subaccount_id,
            denoms=denoms,
        )
        response = await self._execute_call(call=self._stub.SubaccountBalancesList, request=request)

        return response

    async def fetch_subaccount_balance(self, subaccount_id: str, denom: str) -> Dict[str, Any]:
        request = exchange_accounts_pb.SubaccountBalanceEndpointRequest(
            subaccount_id=subaccount_id,
            denom=denom,
        )
        response = await self._execute_call(call=self._stub.SubaccountBalanceEndpoint, request=request)

        return response

    async def fetch_subaccount_history(
        self,
        subaccount_id: str,
        denom: Optional[str] = None,
        transfer_types: Optional[List[str]] = None,
        pagination: Optional[PaginationOption] = None,
    ) -> Dict[str, Any]:
        pagination = pagination or PaginationOption()
        request = exchange_accounts_pb.SubaccountHistoryRequest(
            subaccount_id=subaccount_id,
            denom=denom,
            transfer_types=transfer_types,
            skip=pagination.skip,
            limit=pagination.limit,
            end_time=pagination.end_time,
        )
        response = await self._execute_call(call=self._stub.SubaccountHistory, request=request)

        return response

    async def fetch_subaccount_order_summary(
        self,
        subaccount_id: str,
        market_id: Optional[str] = None,
        order_direction: Optional[str] = None,
    ) -> Dict[str, Any]:
        request = exchange_accounts_pb.SubaccountOrderSummaryRequest(
            subaccount_id=subaccount_id,
            market_id=market_id,
            order_direction=order_direction,
        )
        response = await self._execute_call(call=self._stub.SubaccountOrderSummary, request=request)

        return response

    async def fetch_rewards(self, account_address: Optional[str] = None, epoch: Optional[int] = None) -> Dict[str, Any]:
        request = exchange_accounts_pb.RewardsRequest(account_address=account_address, epoch=epoch)
        response = await self._execute_call(call=self._stub.Rewards, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.evm.v1 import query_pb2 as injective_dot_evm_dot_v1_dot_query__pb2
from pyinjective.proto.injective.evm.v1 import tx_pb2 as injective_dot_evm_dot_v1_dot_tx__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Account = channel.unary_unary(
                '/injective.evm.v1.Query/Account',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryAccountRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryAccountResponse.FromString,
                _registered_method=True)
        self.CosmosAccount = channel.unary_unary(
                '/injective.evm.v1.Query/CosmosAccount',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryCosmosAccountRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryCosmosAccountResponse.FromString,
                _registered_method=True)
        self.ValidatorAccount = channel.unary_unary(
                '/injective.evm.v1.Query/ValidatorAccount',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryValidatorAccountRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryValidatorAccountResponse.FromString,
                _registered_method=True)
        self.Balance = channel.unary_unary(
                '/injective.evm.v1.Query/Balance',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryBalanceRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryBalanceResponse.FromString,
                _registered_method=True)
        self.Storage = channel.unary_unary(
                '/injective.evm.v1.Query/Storage',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryStorageRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryStorageResponse.FromString,
                _registered_method=True)
        self.Code = channel.unary_unary(
                '/injective.evm.v1.Query/Code',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryCodeRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryCodeResponse.FromString,
                _registered_method=True)
        self.Params = channel.unary_unary(
                '/injective.evm.v1.Query/Params',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.EthCall = channel.unary_unary(
                '/injective.evm.v1.Query/EthCall',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.EthCallRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTxResponse.FromString,
                _registered_method=True)
        self.EstimateGas = channel.unary_unary(
                '/injective.evm.v1.Query/EstimateGas',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.EthCallRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.EstimateGasResponse.FromString,
                _registered_method=True)
        self.TraceTx = channel.unary_unary(
                '/injective.evm.v1.Query/TraceTx',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceTxRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceTxResponse.FromString,
                _registered_method=True)
        self.TraceBlock = channel.unary_unary(
                '/injective.evm.v1.Query/TraceBlock',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceBlockRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceBlockResponse.FromString,
                _registered_method=True)
        self.TraceCall = channel.unary_unary(
                '/injective.evm.v1.Query/TraceCall',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceCallRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceCallResponse.FromString,
                _registered_method=True)
        self.BaseFee = channel.unary_unary(
                '/injective.evm.v1.Query/BaseFee',
                request_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryBaseFeeRequest.SerializeToString,
                response_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryBaseFeeResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Account(self, request, context):
        """Account queries an Ethereum account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CosmosAccount(self, request, context):
        """CosmosAccount queries an Ethereum account's Cosmos Address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidatorAccount(self, request, context):
        """ValidatorAccount queries an Ethereum account's from a validator consensus
        Address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Balance(self, request, context):
        """Balance queries the balance of a the EVM denomination for a single
        EthAccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Storage(self, request, context):
        """Storage queries the balance of all coins for a single account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Code(self, request, context):
        """Code queries the code of a single account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params queries the parameters of x/evm module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EthCall(self, request, context):
        """EthCall implements the `eth_call` rpc api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateGas(self, request, context):
        """EstimateGas implements the `eth_estimateGas` rpc api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TraceTx(self, request, context):
        """TraceTx implements the `debug_traceTransaction` rpc api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TraceBlock(self, request, context):
        """TraceBlock implements the `debug_traceBlockByNumber` and
        `debug_traceBlockByHash` rpc api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TraceCall(self, request, context):
        """TraceCall implements the `debug_traceCall` rpc api
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BaseFee(self, request, context):
        """BaseFee queries the base fee of the parent block of the current block,
        it's similar to feemarket module's method, but also checks london hardfork
        status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Account': grpc.unary_unary_rpc_method_handler(
                    servicer.Account,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryAccountRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryAccountResponse.SerializeToString,
            ),
            'CosmosAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.CosmosAccount,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryCosmosAccountRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryCosmosAccountResponse.SerializeToString,
            ),
            'ValidatorAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidatorAccount,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryValidatorAccountRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryValidatorAccountResponse.SerializeToString,
            ),
            'Balance': grpc.unary_unary_rpc_method_handler(
                    servicer.Balance,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryBalanceRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryBalanceResponse.SerializeToString,
            ),
            'Storage': grpc.unary_unary_rpc_method_handler(
                    servicer.Storage,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryStorageRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryStorageResponse.SerializeToString,
            ),
            'Code': grpc.unary_unary_rpc_method_handler(
                    servicer.Code,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryCodeRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryCodeResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'EthCall': grpc.unary_unary_rpc_method_handler(
                    servicer.EthCall,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.EthCallRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTxResponse.SerializeToString,
            ),
            'EstimateGas': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateGas,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.EthCallRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.EstimateGasResponse.SerializeToString,
            ),
            'TraceTx': grpc.unary_unary_rpc_method_handler(
                    servicer.TraceTx,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceTxRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceTxResponse.SerializeToString,
            ),
            'TraceBlock': grpc.unary_unary_rpc_method_handler(
                    servicer.TraceBlock,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceBlockRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceBlockResponse.SerializeToString,
            ),
            'TraceCall': grpc.unary_unary_rpc_method_handler(
                    servicer.TraceCall,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceCallRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceCallResponse.SerializeToString,
            ),
            'BaseFee': grpc.unary_unary_rpc_method_handler(
                    servicer.BaseFee,
                    request_deserializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryBaseFeeRequest.FromString,
                    response_serializer=injective_dot_evm_dot_v1_dot_query__pb2.QueryBaseFeeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.evm.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.evm.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Account(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/Account',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryAccountRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CosmosAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/CosmosAccount',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryCosmosAccountRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryCosmosAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidatorAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/ValidatorAccount',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryValidatorAccountRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryValidatorAccountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Balance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/Balance',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryBalanceRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryBalanceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Storage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/Storage',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryStorageRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryStorageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Code(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/Code',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryCodeRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/Params',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EthCall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/EthCall',
            injective_dot_evm_dot_v1_dot_query__pb2.EthCallRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_tx__pb2.MsgEthereumTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EstimateGas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/EstimateGas',
            injective_dot_evm_dot_v1_dot_query__pb2.EthCallRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.EstimateGasResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TraceTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/TraceTx',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceTxRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceTxResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TraceBlock(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/TraceBlock',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceBlockRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceBlockResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TraceCall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/TraceCall',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceCallRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryTraceCallResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BaseFee(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.evm.v1.Query/BaseFee',
            injective_dot_evm_dot_v1_dot_query__pb2.QueryBaseFeeRequest.SerializeToString,
            injective_dot_evm_dot_v1_dot_query__pb2.QueryBaseFeeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/permissions/v1beta1/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*injective/permissions/v1beta1/params.proto\x12\x1dinjective.permissions.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\"[\n\x06Params\x12\x34\n\x17wasm_hook_query_max_gas\x18\x01 \x01(\x04R\x13wasmHookQueryMaxGas:\x1b\xe8\xa0\x1f\x01\x8a\xe7\xb0*\x12permissions/ParamsB\x99\x02\n!com.injective.permissions.v1beta1B\x0bParamsProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\xa2\x02\x03IPX\xaa\x02\x1dInjective.Permissions.V1beta1\xca\x02\x1dInjective\\Permissions\\V1beta1\xe2\x02)Injective\\Permissions\\V1beta1\\GPBMetadata\xea\x02\x1fInjective::Permissions::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.permissions.v1beta1.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.injective.permissions.v1beta1B\013ParamsProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\242\002\003IPX\252\002\035Injective.Permissions.V1beta1\312\002\035Injective\\Permissions\\V1beta1\342\002)Injective\\Permissions\\V1beta1\\GPBMetadata\352\002\037Injective::Permissions::V1beta1'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\022permissions/Params'
  _globals['_PARAMS']._serialized_start=177
  _globals['_PARAMS']._serialized_end=268
# @@protoc_insertion_point(module_scope)
